@@ -5,11 +5,11 @@ def delta2dict( delta ):
     """Accepts a delta, returns a dictionary of units"""
     delta = abs( delta )
     return { 
-        'year'   : delta.days / 365 ,
-        'day'    : delta.days % 365 ,
-        'hour'   : delta.seconds / 3600 ,
-        'minute' : (delta.seconds / 60) % 60 ,
-        'second' : delta.seconds % 60 ,
+        'year'   : int(delta.days / 365),
+        'day'    : int(delta.days % 365),
+        'hour'   : int(delta.seconds / 3600),
+        'minute' : int(delta.seconds / 60) % 60,
+        'second' : delta.seconds % 60,
         'microsecond' : delta.microseconds
     }
 
@@ -36,6 +36,3 @@ def human(dt, precision=2, past_tense='{} ago', future_tense='in {}'):
     human_delta = ', '.join( hlist )
     return the_tense.format(human_delta) 
 
-if __name__ == "__main__": 
-    from test_ago import test_output
-    test_output()
